==> kie-dmn-validation-999-20250203.023502-186-sources.jar: org/kie/dmn/validation/DMNv1x/Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods1.java <==
package org.kie.dmn.validation.DMNv1x;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.kie.dmn.core.util.MsgUtil;
import org.kie.dmn.model.api.DMNElementReference;
import org.kie.dmn.core.impl.DMNMessageImpl;
import org.kie.dmn.api.core.DMNMessage;
import org.kie.dmn.feel.parser.feel11.FEELParser;
import org.kie.dmn.feel.lang.types.BuiltInType;
import org.kie.dmn.core.compiler.DMNCompilerImpl;
import org.kie.dmn.core.compiler.ImportDMNResolverUtil;
import org.kie.dmn.validation.ValidatorUtil;
import org.kie.dmn.model.api.*;
import org.kie.dmn.model.api.DMNElement;
import org.kie.dmn.api.feel.runtime.events.FEELEvent;
import org.kie.dmn.core.util.Msg;
import org.kie.dmn.feel.runtime.events.SyntaxErrorEvent;
import static org.kie.dmn.validation.ValidatorUtil.getRootItemDef;
import static org.kie.dmn.validation.ValidatorUtil.rightOfHash;
import static org.kie.dmn.validation.ValidatorUtil.nameOrIDOfTable;
import static org.kie.dmn.validation.ValidatorUtil.leftOfHash;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;

public class Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods1 {

    /**
     * Rule name: DTABLE_EMPTY_ENTRY
     */
    public static org.drools.model.Rule rule_DTABLE__EMPTY__ENTRY() {
        final org.drools.model.Variable<org.kie.dmn.model.api.UnaryTests> var_$ie = D.declarationOf(org.kie.dmn.model.api.UnaryTests.class,
                                                                                                    DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_UnaryTests_Metadata_INSTANCE,
                                                                                                    "$ie");
        final org.drools.model.Variable<org.kie.dmn.model.api.DecisionRule> var_$dr = D.declarationOf(org.kie.dmn.model.api.DecisionRule.class,
                                                                                                      DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DecisionRule_Metadata_INSTANCE,
                                                                                                      "$dr",
                                                                                                      D.from(var_$ie,
                                                                                                             org.kie.dmn.validation.DMNv1x.P71.LambdaExtractor711BF753AD51E9B6B3C2D14C8B41523C.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DecisionTable> var_$dt = D.declarationOf(org.kie.dmn.model.api.DecisionTable.class,
                                                                                                       DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DecisionTable_Metadata_INSTANCE,
                                                                                                       "$dt",
                                                                                                       D.from(var_$dr,
                                                                                                              org.kie.dmn.validation.DMNv1x.PAB.LambdaExtractorABBCCE52B79C9AFFF3054ED1062A25C1.INSTANCE));
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DTABLE_EMPTY_ENTRY")
                                      .build(D.pattern(var_$ie).expr("GENERATED_2F20387C2C9EA44BA0BDD1AC5C5050F3",
                                                                     org.kie.dmn.validation.DMNv1x.P20.LambdaPredicate2008E50C74CF18FCB6855BCFDFB44B50.INSTANCE,
                                                                     D.reactOn("text")).expr("GENERATED_55FA94B9DBDE36CEAE49C404B3C9DC81",
                                                                                             org.kie.dmn.validation.DMNv1x.P12.LambdaPredicate1288275231EB6F288B298C4B6EAAB271.INSTANCE,
                                                                                             D.reactOn("parent")),
                                             D.pattern(var_$dr),
                                             D.pattern(var_$dt),
                                             D.on(var_$ie,
                                                  var_$dr,
                                                  var_$dt,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PEA.LambdaConsequenceEA5D05779268824EB83595C564FA84F2.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DTABLE_MULTIPLEOUTPUTCOLLECTOPERATOR
     */
    public static org.drools.model.Rule rule_DTABLE__MULTIPLEOUTPUTCOLLECTOPERATOR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.DecisionTable> var_$dt = D.declarationOf(org.kie.dmn.model.api.DecisionTable.class,
                                                                                                       DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DecisionTable_Metadata_INSTANCE,
                                                                                                       "$dt");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DTABLE_MULTIPLEOUTPUTCOLLECTOPERATOR")
                                      .build(D.pattern(var_$dt).expr("GENERATED_A9C66FF8FDD079DC21F878098CB59239",
                                                                     org.kie.dmn.validation.DMNv1x.PF9.LambdaPredicateF9422E36E1C29B290ACF614724436A29.INSTANCE,
                                                                     D.reactOn("hitPolicy")).expr("GENERATED_48CA0CB4FB22001185FF166BFBEE35ED",
                                                                                                  org.kie.dmn.validation.DMNv1x.PE3.LambdaPredicateE3039BB571D25FA41E73B325AA4F1EA7.INSTANCE,
                                                                                                  D.reactOn("aggregation")).expr("GENERATED_6F9CBCA3C0B49F3CF7A924F7CBE79C34",
                                                                                                                                 org.kie.dmn.validation.DMNv1x.P04.LambdaPredicate04B926FFC0D52E9F4F69EB812FF798B8.INSTANCE,
                                                                                                                                 D.alphaIndexedBy(int.class,
                                                                                                                                                  org.drools.model.Index.ConstraintType.GREATER_THAN,
                                                                                                                                                  -1,
                                                                                                                                                  org.kie.dmn.validation.DMNv1x.P04.LambdaExtractor046B8B8102FABD23DD2C70387B7C3115.INSTANCE,
                                                                                                                                                  1),
                                                                                                                                 D.reactOn("output")),
                                             D.on(var_$dt,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PBA.LambdaConsequenceBA62AFD125AB4251BBC08BA527305032.INSTANCE));
        return rule;
    }

    /**
     * Rule name: BKM_MISSING_EXPR
     */
    public static org.drools.model.Rule rule_BKM__MISSING__EXPR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.BusinessKnowledgeModel> var_$d = D.declarationOf(org.kie.dmn.model.api.BusinessKnowledgeModel.class,
                                                                                                               DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_BusinessKnowledgeModel_Metadata_INSTANCE,
                                                                                                               "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "BKM_MISSING_EXPR")
                                      .build(D.pattern(var_$d).expr("GENERATED_4AC890BEF96CB1311CA1794964D3AA09",
                                                                    org.kie.dmn.validation.DMNv1x.P82.LambdaPredicate82173E250F4C900A2AFA3A355DE15DE5.INSTANCE,
                                                                    D.reactOn("encapsulatedLogic")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PE7.LambdaConsequenceE7098BAE755DF791DD41348C58462DCB.INSTANCE));
        return rule;
    }

    /**
     * Rule name: BKM_MISSING_VAR
     */
    public static org.drools.model.Rule rule_BKM__MISSING__VAR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.BusinessKnowledgeModel> var_$d = D.declarationOf(org.kie.dmn.model.api.BusinessKnowledgeModel.class,
                                                                                                               DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_BusinessKnowledgeModel_Metadata_INSTANCE,
                                                                                                               "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "BKM_MISSING_VAR")
                                      .build(D.pattern(var_$d).expr("GENERATED_2E7E80E3C58A849D8D4B605D0F268B94",
                                                                    org.kie.dmn.validation.DMNv1x.PBC.LambdaPredicateBC1E04C54E550733283328C9C50DCD97.INSTANCE,
                                                                    D.reactOn("variable")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PCF.LambdaConsequenceCF9C36B82D750798B6D82F19C41657BE.INSTANCE));
        return rule;
    }

    /**
     * Rule name: BKM_VAR_MISMATCH
     */
    public static org.drools.model.Rule rule_BKM__VAR__MISMATCH() {
        final org.drools.model.Variable<org.kie.dmn.model.api.BusinessKnowledgeModel> var_$d = D.declarationOf(org.kie.dmn.model.api.BusinessKnowledgeModel.class,
                                                                                                               DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_BusinessKnowledgeModel_Metadata_INSTANCE,
                                                                                                               "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "BKM_VAR_MISMATCH")
                                      .build(D.pattern(var_$d).expr("GENERATED_23D6AEF0194288B83EF78D267D4C431F",
                                                                    org.kie.dmn.validation.DMNv1x.PB8.LambdaPredicateB82D17A6D9606B76D7FE46D911545E91.INSTANCE,
                                                                    D.reactOn("variable")).expr("GENERATED_D28479BFCB060AF7E788666DE6215E51",
                                                                                                org.kie.dmn.validation.DMNv1x.P87.LambdaPredicate8745AC5ECA7E2C9842E75884FCC6F73C.INSTANCE,
                                                                                                D.reactOn("name",
                                                                                                          "variable")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PFB.LambdaConsequenceFB5D45425379D9A38FC0BE39286AE6F5.INSTANCE));
        return rule;
    }
}

==> kie-dmn-validation-999-20250415.023218-243-sources.jar: org/kie/dmn/validation/DMNv1x/Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods1.java <==
package org.kie.dmn.validation.DMNv1x;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.kie.dmn.core.util.MsgUtil;
import org.kie.dmn.model.api.DMNElementReference;
import org.kie.dmn.core.impl.DMNMessageImpl;
import org.kie.dmn.api.core.DMNMessage;
import org.kie.dmn.feel.parser.feel11.FEELParser;
import org.kie.dmn.feel.lang.types.BuiltInType;
import org.kie.dmn.core.compiler.DMNCompilerImpl;
import org.kie.dmn.core.compiler.DMNImportsUtil;
import org.kie.dmn.validation.ValidatorUtil;
import org.kie.dmn.model.api.*;
import org.kie.dmn.model.api.DMNElement;
import org.kie.dmn.api.feel.runtime.events.FEELEvent;
import org.kie.dmn.core.util.Msg;
import org.kie.dmn.feel.runtime.events.SyntaxErrorEvent;
import static org.kie.dmn.validation.ValidatorUtil.getRootItemDef;
import static org.kie.dmn.validation.ValidatorUtil.rightOfHash;
import static org.kie.dmn.validation.ValidatorUtil.nameOrIDOfTable;
import static org.kie.dmn.validation.ValidatorUtil.leftOfHash;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;

public class Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods1 {

    /**
     * Rule name: DTABLE_EMPTY_ENTRY
     */
    public static org.drools.model.Rule rule_DTABLE__EMPTY__ENTRY() {
        final org.drools.model.Variable<org.kie.dmn.model.api.UnaryTests> var_$ie = D.declarationOf(org.kie.dmn.model.api.UnaryTests.class,
                                                                                                    DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_UnaryTests_Metadata_INSTANCE,
                                                                                                    "$ie");
        final org.drools.model.Variable<org.kie.dmn.model.api.DecisionRule> var_$dr = D.declarationOf(org.kie.dmn.model.api.DecisionRule.class,
                                                                                                      DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DecisionRule_Metadata_INSTANCE,
                                                                                                      "$dr",
                                                                                                      D.from(var_$ie,
                                                                                                             org.kie.dmn.validation.DMNv1x.PB7.LambdaExtractorB700B8798CC789ECE7BC757B6FF30ACC.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DecisionTable> var_$dt = D.declarationOf(org.kie.dmn.model.api.DecisionTable.class,
                                                                                                       DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DecisionTable_Metadata_INSTANCE,
                                                                                                       "$dt",
                                                                                                       D.from(var_$dr,
                                                                                                              org.kie.dmn.validation.DMNv1x.P6E.LambdaExtractor6E9C5BD7D248CA5D8303AE4FAF679F3C.INSTANCE));
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DTABLE_EMPTY_ENTRY")
                                      .build(D.pattern(var_$ie).expr("GENERATED_2F20387C2C9EA44BA0BDD1AC5C5050F3",
                                                                     org.kie.dmn.validation.DMNv1x.P18.LambdaPredicate188D703AABF514B3B3E00FA2CC3F7509.INSTANCE,
                                                                     D.reactOn("text")).expr("GENERATED_55FA94B9DBDE36CEAE49C404B3C9DC81",
                                                                                             org.kie.dmn.validation.DMNv1x.PB4.LambdaPredicateB456432A3996424577FC995A694BCD6B.INSTANCE,
                                                                                             D.reactOn("parent")),
                                             D.pattern(var_$dr),
                                             D.pattern(var_$dt),
                                             D.on(var_$ie,
                                                  var_$dr,
                                                  var_$dt,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P8D.LambdaConsequence8D5D91B74E7F3260C9D9965961AD6D03.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DTABLE_MULTIPLEOUTPUTCOLLECTOPERATOR
     */
    public static org.drools.model.Rule rule_DTABLE__MULTIPLEOUTPUTCOLLECTOPERATOR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.DecisionTable> var_$dt = D.declarationOf(org.kie.dmn.model.api.DecisionTable.class,
                                                                                                       DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DecisionTable_Metadata_INSTANCE,
                                                                                                       "$dt");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DTABLE_MULTIPLEOUTPUTCOLLECTOPERATOR")
                                      .build(D.pattern(var_$dt).expr("GENERATED_A9C66FF8FDD079DC21F878098CB59239",
                                                                     org.kie.dmn.validation.DMNv1x.P08.LambdaPredicate08186AE5737CFE2D78E440B2E5660AEB.INSTANCE,
                                                                     D.reactOn("hitPolicy")).expr("GENERATED_48CA0CB4FB22001185FF166BFBEE35ED",
                                                                                                  org.kie.dmn.validation.DMNv1x.P55.LambdaPredicate554652DDDAF222DD6D0C7054B4567183.INSTANCE,
                                                                                                  D.reactOn("aggregation")).expr("GENERATED_6F9CBCA3C0B49F3CF7A924F7CBE79C34",
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PD5.LambdaPredicateD5AC9BF700D79E344B25EFFC70964CAB.INSTANCE,
                                                                                                                                 D.alphaIndexedBy(int.class,
                                                                                                                                                  org.drools.model.Index.ConstraintType.GREATER_THAN,
                                                                                                                                                  -1,
                                                                                                                                                  org.kie.dmn.validation.DMNv1x.P42.LambdaExtractor42FDFE2321FD031617A2E66CE994AF11.INSTANCE,
                                                                                                                                                  1),
                                                                                                                                 D.reactOn("output")),
                                             D.on(var_$dt,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P40.LambdaConsequence40D3362A03E60712A39D21A833C7AC51.INSTANCE));
        return rule;
    }

    /**
     * Rule name: BKM_MISSING_EXPR
     */
    public static org.drools.model.Rule rule_BKM__MISSING__EXPR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.BusinessKnowledgeModel> var_$d = D.declarationOf(org.kie.dmn.model.api.BusinessKnowledgeModel.class,
                                                                                                               DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_BusinessKnowledgeModel_Metadata_INSTANCE,
                                                                                                               "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "BKM_MISSING_EXPR")
                                      .build(D.pattern(var_$d).expr("GENERATED_4AC890BEF96CB1311CA1794964D3AA09",
                                                                    org.kie.dmn.validation.DMNv1x.PBF.LambdaPredicateBFA03D9D1CBBC89597932413D459D39E.INSTANCE,
                                                                    D.reactOn("encapsulatedLogic")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P95.LambdaConsequence95AF026720E0A23BBEAE2A19603ED8D3.INSTANCE));
        return rule;
    }

    /**
     * Rule name: BKM_MISSING_VAR
     */
    public static org.drools.model.Rule rule_BKM__MISSING__VAR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.BusinessKnowledgeModel> var_$d = D.declarationOf(org.kie.dmn.model.api.BusinessKnowledgeModel.class,
                                                                                                               DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_BusinessKnowledgeModel_Metadata_INSTANCE,
                                                                                                               "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "BKM_MISSING_VAR")
                                      .build(D.pattern(var_$d).expr("GENERATED_2E7E80E3C58A849D8D4B605D0F268B94",
                                                                    org.kie.dmn.validation.DMNv1x.P5E.LambdaPredicate5E1C2D84EE781CCB63F44873E4D2646A.INSTANCE,
                                                                    D.reactOn("variable")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P01.LambdaConsequence0135D9E3F91A67BFA10923B55DCC922B.INSTANCE));
        return rule;
    }

    /**
     * Rule name: BKM_VAR_MISMATCH
     */
    public static org.drools.model.Rule rule_BKM__VAR__MISMATCH() {
        final org.drools.model.Variable<org.kie.dmn.model.api.BusinessKnowledgeModel> var_$d = D.declarationOf(org.kie.dmn.model.api.BusinessKnowledgeModel.class,
                                                                                                               DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_BusinessKnowledgeModel_Metadata_INSTANCE,
                                                                                                               "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "BKM_VAR_MISMATCH")
                                      .build(D.pattern(var_$d).expr("GENERATED_23D6AEF0194288B83EF78D267D4C431F",
                                                                    org.kie.dmn.validation.DMNv1x.P9A.LambdaPredicate9A0D41B5ED1D6C5E81981833006BD848.INSTANCE,
                                                                    D.reactOn("variable")).expr("GENERATED_D28479BFCB060AF7E788666DE6215E51",
                                                                                                org.kie.dmn.validation.DMNv1x.PEF.LambdaPredicateEF4AA36BF6A79EBF5BFA943CE2583366.INSTANCE,
                                                                                                D.reactOn("name",
                                                                                                          "variable")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PD6.LambdaConsequenceD6BA32D03C83A89651F89862F080522D.INSTANCE));
        return rule;
    }
}
